import { SemanticMark } from "./semantic-mark";

import { GrammarMarkType, Factory } from "@visactor/vgrammar-core";

import { PlotMakType } from "./enums";

import { field as getFieldAccessor } from "@visactor/vgrammar-util";

import { merge } from "@visactor/vutils";

export class WordcloudShapeSemanticMark extends SemanticMark {
    constructor(id) {
        super(PlotMakType.wordcloudShape, id), Factory.getTransform(PlotMakType.wordcloudShape) || this._logger.error("Please add this line of code:\n          import { registerWordCloudShapeTransforms } from '@visactor/vgrammar-wordcloud-shape'; \n        and run registerWordCloudShapeTransforms() before use wordcloud-shape");
    }
    setMarkType() {
        return GrammarMarkType.text;
    }
    setDefaultMarkTransform() {
        var _a;
        return [ {
            type: "wordcloudShape",
            size: {
                callback: params => [ params.viewBox.width(), params.viewBox.height() ],
                dependency: [ "viewBox" ]
            },
            dataIndexKey: "text_key",
            colorList: this.getPalette(),
            text: {
                field: null === (_a = this.spec.encode) || void 0 === _a ? void 0 : _a.text
            }
        } ];
    }
    setMainMarkSpec(parsedMainSpec) {
        var _a;
        const shapeTransform = parsedMainSpec.transform ? parsedMainSpec.transform.find((entry => "wordcloudShape" === entry.type)) : null;
        return shapeTransform ? {
            key: null !== (_a = shapeTransform.dataIndexKey) && void 0 !== _a ? _a : "defaultDataIndexKey"
        } : {};
    }
    setMainMarkEnterEncode() {
        return merge({
            textAlign: "center",
            textBaseline: "alphabetic"
        }, this.spec.style);
    }
    parseScaleByEncode(channel, option) {
        return "color" === channel ? {
            type: "ordinal",
            id: this.getScaleId("color"),
            domain: {
                data: this.getDataIdOfFiltered(),
                field: option
            },
            range: this.getPalette()
        } : null;
    }
    convertMarkEncode(encode) {
        var _a, _b, _c, _d;
        const markEncoder = this.convertSimpleMarkEncode(encode), res = {
            x: {
                field: "x"
            },
            y: {
                field: "y"
            },
            angle: {
                field: "angle"
            },
            fontSize: {
                field: "fontSize"
            },
            fontStyle: {
                field: "fontStyle"
            },
            fontFamily: {
                field: "fontFamily"
            },
            fontWeight: {
                field: "fontWeight"
            },
            fillOpacity: {
                field: "opacity"
            },
            text: {
                field: null === (_a = this.spec.encode) || void 0 === _a ? void 0 : _a.text
            }
        };
        if (markEncoder.stroke && (res.stroke = markEncoder.stroke), markEncoder.color) {
            const scaleColorId = this.getScaleId("color"), colorAccessor = getFieldAccessor(markEncoder.color.field);
            res.fill = (datum, el, params) => params[scaleColorId].scale(colorAccessor(datum));
        } else res.fill = null !== (_c = null === (_b = this.spec.style) || void 0 === _b ? void 0 : _b.fill) && void 0 !== _c ? _c : null === (_d = this.getPalette()) || void 0 === _d ? void 0 : _d[0];
        return res;
    }
    parseLabelSpec() {
        return {
            marks: [],
            interactions: []
        };
    }
}

WordcloudShapeSemanticMark.type = PlotMakType.wordcloudShape;
//# sourceMappingURL=wordcloud-shape.js.map