import { SemanticMark } from "./semantic-mark";

import { GrammarMarkType, Factory } from "@visactor/vgrammar-core";

import { PlotMakType } from "./enums";

import { field as getFieldAccessor } from "@visactor/vgrammar-util";

export class WordcloudSemanticMark extends SemanticMark {
    constructor(id) {
        super(PlotMakType.wordcloud, id), Factory.getTransform(PlotMakType.wordcloud) || this._logger.error("Please add this line of code:\n         'import { registerWordCloudTransforms } from '@visactor/vgrammar-wordcloud'; \n        and run registerWordCloudTransforms() before use wordcloud");
    }
    setMarkType() {
        return GrammarMarkType.text;
    }
    setDefaultMarkTransform() {
        var _a;
        return [ {
            type: "wordcloud",
            size: {
                callback: params => [ params.viewBox.width(), params.viewBox.height() ],
                dependency: [ "viewBox" ]
            },
            text: {
                field: null === (_a = this.spec.encode) || void 0 === _a ? void 0 : _a.text
            }
        } ];
    }
    parseScaleByEncode(channel, option) {
        return "color" === channel ? {
            type: "ordinal",
            id: this.getScaleId("color"),
            domain: {
                data: this.getDataIdOfFiltered(),
                field: option
            },
            range: this.getPalette()
        } : null;
    }
    convertMarkEncode(encode) {
        var _a, _b, _c, _d;
        const markEncoder = this.convertSimpleMarkEncode(encode), res = {
            x: {
                field: "x"
            },
            y: {
                field: "y"
            },
            angle: {
                field: "angle"
            },
            fontSize: {
                field: "fontSize"
            },
            fontStyle: {
                field: "fontStyle"
            },
            fontFamily: {
                field: "fontFamily"
            },
            fontWeight: {
                field: "fontWeight"
            },
            text: {
                field: null === (_a = this.spec.encode) || void 0 === _a ? void 0 : _a.text
            }
        };
        if (markEncoder.stroke && (res.stroke = markEncoder.stroke), markEncoder.color) {
            const scaleColorId = this.getScaleId("color"), colorAccessor = getFieldAccessor(markEncoder.color.field);
            res.fill = (datum, el, params) => params[scaleColorId].scale(colorAccessor(datum));
        } else res.fill = null !== (_c = null === (_b = this.spec.style) || void 0 === _b ? void 0 : _b.fill) && void 0 !== _c ? _c : null === (_d = this.getPalette()) || void 0 === _d ? void 0 : _d[0];
        return res;
    }
    parseLabelSpec() {
        return {
            marks: [],
            interactions: []
        };
    }
}

WordcloudSemanticMark.type = PlotMakType.wordcloud;
//# sourceMappingURL=wordcloud.js.map